# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class SOSOPricesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def soso_prices_get(self, _from, to, **kwargs):  # noqa: E501
        """SO-SO prices (SOSO)  # noqa: E501

        This endpoint provides system operator to system operator prices data.  It can be filtered by start time.                This API endpoint has a maximum range of 24 hours.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.soso_prices_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSoSoPrices
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.soso_prices_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.soso_prices_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def soso_prices_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """SO-SO prices (SOSO)  # noqa: E501

        This endpoint provides system operator to system operator prices data.  It can be filtered by start time.                This API endpoint has a maximum range of 24 hours.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.soso_prices_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSoSoPrices
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method soso_prices_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `soso_prices_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `soso_prices_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/soso/prices', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesMiscSoSoPrices',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.reference_api import ReferenceApi  # noqa: E501
from elexonpy.rest import ApiException


class TestReferenceApi(unittest.TestCase):
    """ReferenceApi unit test stubs"""

    def setUp(self):
        self.api = ReferenceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_reference_bmunits_all_get(self):
        """Test case for reference_bmunits_all_get

        BM Units  # noqa: E501
        """
        pass

    def test_reference_fueltypes_all_get(self):
        """Test case for reference_fueltypes_all_get

        Fuel types  # noqa: E501
        """
        pass

    def test_reference_interconnectors_all_get(self):
        """Test case for reference_interconnectors_all_get

        Interconnectors  # noqa: E501
        """
        pass

    def test_reference_remit_assets_all_get(self):
        """Test case for reference_remit_assets_all_get

        Assets  # noqa: E501
        """
        pass

    def test_reference_remit_fueltypes_all_get(self):
        """Test case for reference_remit_fueltypes_all_get

        REMIT fuel types  # noqa: E501
        """
        pass

    def test_reference_remit_participants_all_get(self):
        """Test case for reference_remit_participants_all_get

        Participants  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.models.insights_api_models_responses_demand_outturn_rolling_system_demand import InsightsApiModelsResponsesDemandOutturnRollingSystemDemand  # noqa: E501
from elexonpy.rest import ApiException


class TestInsightsApiModelsResponsesDemandOutturnRollingSystemDemand(unittest.TestCase):
    """InsightsApiModelsResponsesDemandOutturnRollingSystemDemand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInsightsApiModelsResponsesDemandOutturnRollingSystemDemand(self):
        """Test InsightsApiModelsResponsesDemandOutturnRollingSystemDemand"""
        # FIXME: construct object with mandatory attributes with example values
        # model = elexonpy.models.insights_api_models_responses_demand_outturn_rolling_system_demand.InsightsApiModelsResponsesDemandOutturnRollingSystemDemand()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_date_time': 'datetime',
        'settlement_date': 'date',
        'settlement_period': 'int',
        'start_time': 'datetime',
        'adjuster': 'float',
        'price_derivation_code': 'str',
        'system_sell_price': 'float',
        'system_buy_price': 'float',
        'main_price': 'InsightsApiModelsResponsesBalancingSettlementSettlementSummaryPrice',
        'market_price': 'InsightsApiModelsResponsesBalancingSettlementSettlementSummaryPrice'
    }

    attribute_map = {
        'created_date_time': 'createdDateTime',
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'start_time': 'startTime',
        'adjuster': 'adjuster',
        'price_derivation_code': 'priceDerivationCode',
        'system_sell_price': 'systemSellPrice',
        'system_buy_price': 'systemBuyPrice',
        'main_price': 'mainPrice',
        'market_price': 'marketPrice'
    }

    def __init__(self, created_date_time=None, settlement_date=None, settlement_period=None, start_time=None, adjuster=None, price_derivation_code=None, system_sell_price=None, system_buy_price=None, main_price=None, market_price=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._created_date_time = None
        self._settlement_date = None
        self._settlement_period = None
        self._start_time = None
        self._adjuster = None
        self._price_derivation_code = None
        self._system_sell_price = None
        self._system_buy_price = None
        self._main_price = None
        self._market_price = None
        self.discriminator = None
        if created_date_time is not None:
            self.created_date_time = created_date_time
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if start_time is not None:
            self.start_time = start_time
        if adjuster is not None:
            self.adjuster = adjuster
        if price_derivation_code is not None:
            self.price_derivation_code = price_derivation_code
        if system_sell_price is not None:
            self.system_sell_price = system_sell_price
        if system_buy_price is not None:
            self.system_buy_price = system_buy_price
        if main_price is not None:
            self.main_price = main_price
        if market_price is not None:
            self.market_price = market_price

    @property
    def created_date_time(self):
        """Gets the created_date_time of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The created_date_time of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date_time

    @created_date_time.setter
    def created_date_time(self, created_date_time):
        """Sets the created_date_time of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param created_date_time: The created_date_time of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._created_date_time = created_date_time

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param start_time: The start_time of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def adjuster(self):
        """Gets the adjuster of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The adjuster of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._adjuster

    @adjuster.setter
    def adjuster(self, adjuster):
        """Sets the adjuster of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param adjuster: The adjuster of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: float
        """

        self._adjuster = adjuster

    @property
    def price_derivation_code(self):
        """Gets the price_derivation_code of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The price_derivation_code of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._price_derivation_code

    @price_derivation_code.setter
    def price_derivation_code(self, price_derivation_code):
        """Sets the price_derivation_code of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param price_derivation_code: The price_derivation_code of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: str
        """

        self._price_derivation_code = price_derivation_code

    @property
    def system_sell_price(self):
        """Gets the system_sell_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The system_sell_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._system_sell_price

    @system_sell_price.setter
    def system_sell_price(self, system_sell_price):
        """Sets the system_sell_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param system_sell_price: The system_sell_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: float
        """

        self._system_sell_price = system_sell_price

    @property
    def system_buy_price(self):
        """Gets the system_buy_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The system_buy_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._system_buy_price

    @system_buy_price.setter
    def system_buy_price(self, system_buy_price):
        """Sets the system_buy_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param system_buy_price: The system_buy_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: float
        """

        self._system_buy_price = system_buy_price

    @property
    def main_price(self):
        """Gets the main_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The main_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: InsightsApiModelsResponsesBalancingSettlementSettlementSummaryPrice
        """
        return self._main_price

    @main_price.setter
    def main_price(self, main_price):
        """Sets the main_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param main_price: The main_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: InsightsApiModelsResponsesBalancingSettlementSettlementSummaryPrice
        """

        self._main_price = main_price

    @property
    def market_price(self):
        """Gets the market_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501


        :return: The market_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :rtype: InsightsApiModelsResponsesBalancingSettlementSettlementSummaryPrice
        """
        return self._market_price

    @market_price.setter
    def market_price(self, market_price):
        """Sets the market_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.


        :param market_price: The market_price of this InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse.  # noqa: E501
        :type: InsightsApiModelsResponsesBalancingSettlementSettlementSummaryPrice
        """

        self._market_price = market_price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingSettlementSettlementSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.loss_of_load_probability_and_de_rated_margin_api import LossOfLoadProbabilityAndDeRatedMarginApi  # noqa: E501
from elexonpy.rest import ApiException


class TestLossOfLoadProbabilityAndDeRatedMarginApi(unittest.TestCase):
    """LossOfLoadProbabilityAndDeRatedMarginApi unit test stubs"""

    def setUp(self):
        self.api = LossOfLoadProbabilityAndDeRatedMarginApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_lolpdrm_forecast_evolution_get(self):
        """Test case for lolpdrm_forecast_evolution_get

        Loss of load probability and de-rated margin forecast (LOLPDRM)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_period_min_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData  # noqa: E501
from elexonpy.rest import ApiException


class TestInsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData(unittest.TestCase):
    """InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData(self):
        """Test InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_period_min_data.InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'settlement_date': 'date',
        'settlement_period': 'int',
        'net_buy_price_cost_adjustment_energy': 'float',
        'net_buy_price_volume_adjustment_energy': 'float',
        'net_buy_price_volume_adjustment_system': 'float',
        'buy_price_price_adjustment': 'float',
        'net_sell_price_cost_adjustment_energy': 'float',
        'net_sell_price_volume_adjustment_energy': 'float',
        'net_sell_price_volume_adjustment_system': 'float',
        'sell_price_price_adjustment': 'float'
    }

    attribute_map = {
        'dataset': 'dataset',
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'net_buy_price_cost_adjustment_energy': 'netBuyPriceCostAdjustmentEnergy',
        'net_buy_price_volume_adjustment_energy': 'netBuyPriceVolumeAdjustmentEnergy',
        'net_buy_price_volume_adjustment_system': 'netBuyPriceVolumeAdjustmentSystem',
        'buy_price_price_adjustment': 'buyPricePriceAdjustment',
        'net_sell_price_cost_adjustment_energy': 'netSellPriceCostAdjustmentEnergy',
        'net_sell_price_volume_adjustment_energy': 'netSellPriceVolumeAdjustmentEnergy',
        'net_sell_price_volume_adjustment_system': 'netSellPriceVolumeAdjustmentSystem',
        'sell_price_price_adjustment': 'sellPricePriceAdjustment'
    }

    def __init__(self, dataset=None, settlement_date=None, settlement_period=None, net_buy_price_cost_adjustment_energy=None, net_buy_price_volume_adjustment_energy=None, net_buy_price_volume_adjustment_system=None, buy_price_price_adjustment=None, net_sell_price_cost_adjustment_energy=None, net_sell_price_volume_adjustment_energy=None, net_sell_price_volume_adjustment_system=None, sell_price_price_adjustment=None):  # noqa: E501
        """InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._settlement_date = None
        self._settlement_period = None
        self._net_buy_price_cost_adjustment_energy = None
        self._net_buy_price_volume_adjustment_energy = None
        self._net_buy_price_volume_adjustment_system = None
        self._buy_price_price_adjustment = None
        self._net_sell_price_cost_adjustment_energy = None
        self._net_sell_price_volume_adjustment_energy = None
        self._net_sell_price_volume_adjustment_system = None
        self._sell_price_price_adjustment = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if net_buy_price_cost_adjustment_energy is not None:
            self.net_buy_price_cost_adjustment_energy = net_buy_price_cost_adjustment_energy
        if net_buy_price_volume_adjustment_energy is not None:
            self.net_buy_price_volume_adjustment_energy = net_buy_price_volume_adjustment_energy
        if net_buy_price_volume_adjustment_system is not None:
            self.net_buy_price_volume_adjustment_system = net_buy_price_volume_adjustment_system
        if buy_price_price_adjustment is not None:
            self.buy_price_price_adjustment = buy_price_price_adjustment
        if net_sell_price_cost_adjustment_energy is not None:
            self.net_sell_price_cost_adjustment_energy = net_sell_price_cost_adjustment_energy
        if net_sell_price_volume_adjustment_energy is not None:
            self.net_sell_price_volume_adjustment_energy = net_sell_price_volume_adjustment_energy
        if net_sell_price_volume_adjustment_system is not None:
            self.net_sell_price_volume_adjustment_system = net_sell_price_volume_adjustment_system
        if sell_price_price_adjustment is not None:
            self.sell_price_price_adjustment = sell_price_price_adjustment

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param dataset: The dataset of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def net_buy_price_cost_adjustment_energy(self):
        """Gets the net_buy_price_cost_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The net_buy_price_cost_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: float
        """
        return self._net_buy_price_cost_adjustment_energy

    @net_buy_price_cost_adjustment_energy.setter
    def net_buy_price_cost_adjustment_energy(self, net_buy_price_cost_adjustment_energy):
        """Sets the net_buy_price_cost_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param net_buy_price_cost_adjustment_energy: The net_buy_price_cost_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: float
        """

        self._net_buy_price_cost_adjustment_energy = net_buy_price_cost_adjustment_energy

    @property
    def net_buy_price_volume_adjustment_energy(self):
        """Gets the net_buy_price_volume_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The net_buy_price_volume_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: float
        """
        return self._net_buy_price_volume_adjustment_energy

    @net_buy_price_volume_adjustment_energy.setter
    def net_buy_price_volume_adjustment_energy(self, net_buy_price_volume_adjustment_energy):
        """Sets the net_buy_price_volume_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param net_buy_price_volume_adjustment_energy: The net_buy_price_volume_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: float
        """

        self._net_buy_price_volume_adjustment_energy = net_buy_price_volume_adjustment_energy

    @property
    def net_buy_price_volume_adjustment_system(self):
        """Gets the net_buy_price_volume_adjustment_system of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The net_buy_price_volume_adjustment_system of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: float
        """
        return self._net_buy_price_volume_adjustment_system

    @net_buy_price_volume_adjustment_system.setter
    def net_buy_price_volume_adjustment_system(self, net_buy_price_volume_adjustment_system):
        """Sets the net_buy_price_volume_adjustment_system of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param net_buy_price_volume_adjustment_system: The net_buy_price_volume_adjustment_system of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: float
        """

        self._net_buy_price_volume_adjustment_system = net_buy_price_volume_adjustment_system

    @property
    def buy_price_price_adjustment(self):
        """Gets the buy_price_price_adjustment of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The buy_price_price_adjustment of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: float
        """
        return self._buy_price_price_adjustment

    @buy_price_price_adjustment.setter
    def buy_price_price_adjustment(self, buy_price_price_adjustment):
        """Sets the buy_price_price_adjustment of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param buy_price_price_adjustment: The buy_price_price_adjustment of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: float
        """

        self._buy_price_price_adjustment = buy_price_price_adjustment

    @property
    def net_sell_price_cost_adjustment_energy(self):
        """Gets the net_sell_price_cost_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The net_sell_price_cost_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: float
        """
        return self._net_sell_price_cost_adjustment_energy

    @net_sell_price_cost_adjustment_energy.setter
    def net_sell_price_cost_adjustment_energy(self, net_sell_price_cost_adjustment_energy):
        """Sets the net_sell_price_cost_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param net_sell_price_cost_adjustment_energy: The net_sell_price_cost_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: float
        """

        self._net_sell_price_cost_adjustment_energy = net_sell_price_cost_adjustment_energy

    @property
    def net_sell_price_volume_adjustment_energy(self):
        """Gets the net_sell_price_volume_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The net_sell_price_volume_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: float
        """
        return self._net_sell_price_volume_adjustment_energy

    @net_sell_price_volume_adjustment_energy.setter
    def net_sell_price_volume_adjustment_energy(self, net_sell_price_volume_adjustment_energy):
        """Sets the net_sell_price_volume_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param net_sell_price_volume_adjustment_energy: The net_sell_price_volume_adjustment_energy of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: float
        """

        self._net_sell_price_volume_adjustment_energy = net_sell_price_volume_adjustment_energy

    @property
    def net_sell_price_volume_adjustment_system(self):
        """Gets the net_sell_price_volume_adjustment_system of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The net_sell_price_volume_adjustment_system of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: float
        """
        return self._net_sell_price_volume_adjustment_system

    @net_sell_price_volume_adjustment_system.setter
    def net_sell_price_volume_adjustment_system(self, net_sell_price_volume_adjustment_system):
        """Sets the net_sell_price_volume_adjustment_system of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param net_sell_price_volume_adjustment_system: The net_sell_price_volume_adjustment_system of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: float
        """

        self._net_sell_price_volume_adjustment_system = net_sell_price_volume_adjustment_system

    @property
    def sell_price_price_adjustment(self):
        """Gets the sell_price_price_adjustment of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501


        :return: The sell_price_price_adjustment of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :rtype: float
        """
        return self._sell_price_price_adjustment

    @sell_price_price_adjustment.setter
    def sell_price_price_adjustment(self, sell_price_price_adjustment):
        """Sets the sell_price_price_adjustment of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.


        :param sell_price_price_adjustment: The sell_price_price_adjustment of this InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData.  # noqa: E501
        :type: float
        """

        self._sell_price_price_adjustment = sell_price_price_adjustment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesBalancingDatasetRowsNetBalancingServicesAdjustmentData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset': 'str',
        'generation': 'int',
        'publish_time': 'datetime',
        'start_time': 'datetime',
        'settlement_date': 'date',
        'settlement_period': 'int',
        'boundary': 'str'
    }

    attribute_map = {
        'dataset': 'dataset',
        'generation': 'generation',
        'publish_time': 'publishTime',
        'start_time': 'startTime',
        'settlement_date': 'settlementDate',
        'settlement_period': 'settlementPeriod',
        'boundary': 'boundary'
    }

    def __init__(self, dataset=None, generation=None, publish_time=None, start_time=None, settlement_date=None, settlement_period=None, boundary=None):  # noqa: E501
        """InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration - a model defined in Swagger"""  # noqa: E501
        self._dataset = None
        self._generation = None
        self._publish_time = None
        self._start_time = None
        self._settlement_date = None
        self._settlement_period = None
        self._boundary = None
        self.discriminator = None
        if dataset is not None:
            self.dataset = dataset
        if generation is not None:
            self.generation = generation
        if publish_time is not None:
            self.publish_time = publish_time
        if start_time is not None:
            self.start_time = start_time
        if settlement_date is not None:
            self.settlement_date = settlement_date
        if settlement_period is not None:
            self.settlement_period = settlement_period
        if boundary is not None:
            self.boundary = boundary

    @property
    def dataset(self):
        """Gets the dataset of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501


        :return: The dataset of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :rtype: str
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.


        :param dataset: The dataset of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :type: str
        """

        self._dataset = dataset

    @property
    def generation(self):
        """Gets the generation of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501


        :return: The generation of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :rtype: int
        """
        return self._generation

    @generation.setter
    def generation(self, generation):
        """Sets the generation of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.


        :param generation: The generation of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :type: int
        """

        self._generation = generation

    @property
    def publish_time(self):
        """Gets the publish_time of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501


        :return: The publish_time of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_time

    @publish_time.setter
    def publish_time(self, publish_time):
        """Sets the publish_time of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.


        :param publish_time: The publish_time of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :type: datetime
        """

        self._publish_time = publish_time

    @property
    def start_time(self):
        """Gets the start_time of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501


        :return: The start_time of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.


        :param start_time: The start_time of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def settlement_date(self):
        """Gets the settlement_date of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501


        :return: The settlement_date of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :rtype: date
        """
        return self._settlement_date

    @settlement_date.setter
    def settlement_date(self, settlement_date):
        """Sets the settlement_date of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.


        :param settlement_date: The settlement_date of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :type: date
        """

        self._settlement_date = settlement_date

    @property
    def settlement_period(self):
        """Gets the settlement_period of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501


        :return: The settlement_period of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :rtype: int
        """
        return self._settlement_period

    @settlement_period.setter
    def settlement_period(self, settlement_period):
        """Sets the settlement_period of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.


        :param settlement_period: The settlement_period of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :type: int
        """

        self._settlement_period = settlement_period

    @property
    def boundary(self):
        """Gets the boundary of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501


        :return: The boundary of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :rtype: str
        """
        return self._boundary

    @boundary.setter
    def boundary(self, boundary):
        """Sets the boundary of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.


        :param boundary: The boundary of this InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration.  # noqa: E501
        :type: str
        """

        self._boundary = boundary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InsightsApiModelsResponsesIndicatedForecastDatasetRowsIndicatedGeneration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
